﻿
Namespace FRInterfaces
    ''' <summary>
    ''' This is collention interface which will be implemented by all collections (Tags, Files and Transactions)
    ''' </summary>
    ''' <typeparam name="T">T is a generic class which can be Tag, File or Transaction</typeparam>
    ''' <remarks>This must be implemented by custom collection class</remarks>
    Public Interface ICollectionCommon(Of T As Class)
        Inherits IEnumerable

        Function Exists(ByVal oKey As Object) As Boolean

        ReadOnly Property Count() As Long

        Sub Remove(ByVal oKey As Object)

        Function Add(Optional ByVal oObject As T = Nothing, Optional ByVal sKey As String = "") As T

        Default ReadOnly Property Item(ByVal oKey As Object) As T

    End Interface

    ''' <summary>
    ''' Tag is simple interface with a particular tag and it value
    ''' </summary>
    ''' <remarks>This must be implemented by Tag class</remarks>
    Public Interface ITag
        Property Tag() As String
        Property TagValue() As String
    End Interface

    ''' <summary>
    ''' This is Transaction Interface. A transaction is collection of Tags
    ''' </summary>
    ''' <remarks>This must be implemented by Transaction class</remarks>
    Public Interface ITransaction
        Property Tags() As ICollectionCommon(Of ITag)
    End Interface

    ''' <summary>
    ''' This is FileInformation Interface which represents a particular physical file and its contents. A file consists of Tags and/or Transactions which in turn may consist of Tags.
    ''' </summary>
    ''' <remarks>This must me implemented by FileInformation class</remarks>
    Public Interface IFileInformation
        ReadOnly Property FileName() As String
        ReadOnly Property FileType() As FileType
        ReadOnly Property BICForwardingBank() As String
        ReadOnly Property BICExecutingBank() As String
        ReadOnly Property GetFileLevelTags() As ICollectionCommon(Of ITag)
        ReadOnly Property TimeStamp() As String
        ReadOnly Property Transactions() As ICollectionCommon(Of ITransaction)
        Sub GetFileInfo(ByVal sFileName As String)
    End Interface

    ''' <summary>
    ''' Enum to define the type of file.
    ''' </summary>
    ''' <remarks>A file must be one of these types.</remarks>
    Public Enum FileType
        frFileTypeUnknown
        frFileTypeDriectDebit
        frFileTypeDirectCredit
    End Enum

End Namespace
